==> orangehrm-3.0.1.zip: orangehrm-3.0.1/symfony/plugins/orangehrmPimPlugin/modules/pim/actions/deleteImmigrationAction.class.php <==
<?php

/**
 * OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
 * all the essential functionalities required for any enterprise.
 * Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com
 *
 * OrangeHRM is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */
class deleteImmigrationAction extends basePimAction {

    public function execute($request) {
        $deleteIds = $request->getParameter('chkImmigration');
        $empNumber = $request->getParameter('empNumber');
        
        $this->immigrationPermission = $this->getDataGroupPermissions('immigration', $empNumber);

        if ($request->isMethod('post')) {
            if (!$this->IsActionAccessible($empNumber)) {
                $this->forward(sfConfig::get('sf_secure_module'), sfConfig::get('sf_secure_action'));
            }
            if ($this->immigrationPermission->canDelete()) {
                $this->getEmployeeService()->deleteEmployeeImmigrationRecords($empNumber, $deleteIds);
                $this->getUser()->setFlash('immigration.success', __(TopLevelMessages::DELETE_SUCCESS));
                $this->redirect('pim/viewImmigration?empNumber=' . $empNumber);
            }
        }
    }

}

==> orangehrm-3.3.3.zip: orangehrm-3.3.3/symfony/plugins/orangehrmPimPlugin/modules/pim/actions/deleteImmigrationAction.class.php <==
<?php

/**
 * OrangeHRM is a comprehensive Human Resource Management (HRM) System that captures
 * all the essential functionalities required for any enterprise.
 * Copyright (C) 2006 OrangeHRM Inc., http://www.orangehrm.com
 *
 * OrangeHRM is free software; you can redistribute it and/or modify it under the terms of
 * the GNU General Public License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * OrangeHRM is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along with this program;
 * if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA
 */
class deleteImmigrationAction extends basePimAction {

    public function execute($request) {
        $form = new DefaultListForm();
        $form->bind($request->getParameter($form->getName()));
        $deleteIds = $request->getParameter('chkImmigration');
        $empNumber = $request->getParameter('empNumber');
        
        $this->immigrationPermission = $this->getDataGroupPermissions('immigration', $empNumber);

        if ($request->isMethod('post')) {
            if (!$this->IsActionAccessible($empNumber)) {
                $this->forward(sfConfig::get('sf_secure_module'), sfConfig::get('sf_secure_action'));
            }
            if ($this->immigrationPermission->canDelete()) {
                if ($form->isValid()) {
                    $this->getEmployeeService()->deleteEmployeeImmigrationRecords($empNumber, $deleteIds);
                    $this->getUser()->setFlash('immigration.success', __(TopLevelMessages::DELETE_SUCCESS));
                }
                $this->redirect('pim/viewImmigration?empNumber=' . $empNumber);
            }
        }
    }

}
